IF NOT EXISTS(SELECT [name]
	  FROM 	 sysobjects 
	  WHERE  [name] = N'webolize_projects' 
	  AND 	 type = 'U')
BEGIN
	CREATE TABLE [dbo].[webolize_projects](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[fk_siteId] [int] NULL,
		[forum_type] [varchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[forum_type_version] [int] NULL,
		[forum_name] [nvarchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[description] [nvarchar](200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[short_name] [nvarchar](12) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[fk_department] [int] NULL,
		[created_date] [datetime] NULL,
		[created_by] [int] NULL,
		[closed_date] [datetime] NULL,
		[closed_by] [int] NULL,
		[closed] [bit] NULL,
		[contact_person] [int] NULL,
		[contact_department] [int] NULL,
		[department_account] [varchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[group_managers] [int] NULL,
		[group_producers] [int] NULL,
		[group_viewers] [int] NULL,
		[fk_issue] [int] NOT NULL,
		[forum_settings] [nvarchar](max) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
	) ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_projects] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_projects_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [DF_webolize_projects_closed]  DEFAULT ((0)) FOR [closed],
		CONSTRAINT [DF_webolize_projects_fk_issue]  DEFAULT ((-1)) FOR [fk_issue],
		CONSTRAINT [DF_webolize_projects_contact_person]  DEFAULT ((-1)) FOR [contact_person],
		CONSTRAINT [DF_webolize_projects_fk_department]  DEFAULT ((-1)) FOR [fk_department],
		CONSTRAINT [DF_webolize_projects_group_managers]  DEFAULT ((-1)) FOR [group_managers],
		CONSTRAINT [DF_webolize_projects_group_producers]  DEFAULT ((-1)) FOR [group_producers],
		CONSTRAINT [DF_webolize_projects_group_viewers]  DEFAULT ((-1)) FOR [group_viewers],
		CONSTRAINT [PK_webolize_projects_id] PRIMARY KEY CLUSTERED 
		(
			[pk_id]
		)  ON [PRIMARY] 

END


IF NOT EXISTS(SELECT [name] 
	  FROM 	 sysobjects 
	  WHERE  [name] = N'webolize_servicetypes' 
	  AND 	 type = 'U')
BEGIN
	CREATE TABLE [dbo].[webolize_servicetypes](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[name] [nvarchar](128) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[short_name] [nvarchar](12) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[description] [nvarchar](1000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[rate_per_hour] [money] NOT NULL,
		[ordering] [int] NULL,
		[active] [bit] NOT NULL,
		[created_by] [int] NULL,
		[created_date] [datetime] NOT NULL
	) ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_servicetypes] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_servicetypes_rate_per_hour]  DEFAULT ((0.00)) FOR [rate_per_hour],
		CONSTRAINT [DF_webolize_servicetypes_active]  DEFAULT ((1)) FOR [active],
		CONSTRAINT [DF_webolize_servicetypes_created_by]  DEFAULT ((-1)) FOR [created_by],
		CONSTRAINT [DF_webolize_servicetypes_ordering]  DEFAULT ((10)) FOR [ordering],
		CONSTRAINT [DF_webolize_servicetypes_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [PK_webolize_servicetypes] PRIMARY KEY CLUSTERED 
		(
			[pk_id]
		)  ON [PRIMARY] 

	INSERT INTO [dbo].[webolize_servicetypes]
			   ([name],[short_name],[rate_per_hour],[created_by])
		 VALUES
			   ('Billable','Billable',100.00,1)

	INSERT INTO [dbo].[webolize_servicetypes]
			   ([name],[short_name],[rate_per_hour],[created_by])
		 VALUES
			   ('Non-Billable','Non-Billable',0.00,1)
END

--GO

IF NOT EXISTS(SELECT [name] 
	  FROM 	 sysobjects 
	  WHERE  [name] = N'webolize_timeentries' 
	  AND 	 type = 'U')
BEGIN
	CREATE TABLE [dbo].[webolize_timeentries](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[fk_user] [int] NOT NULL,
		[fk_project] [int] NOT NULL,
		[fk_topic] [int] NOT NULL,
		[fk_servicetype] [int] NOT NULL,
		[work_date] [datetime] NOT NULL,
		[minutes] [int] NOT NULL,
		[notes] [nvarchar](128) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[created_by] [int] NOT NULL,
		[created_date] [datetime] NOT NULL,
	) ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_timeentries] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_timeentries_fk_topic]  DEFAULT ((-1)) FOR [fk_topic],
		CONSTRAINT [DF_webolize_timeentries_fk_servicetype]  DEFAULT ((-1)) FOR [fk_servicetype],
		CONSTRAINT [DF_webolize_timeentries_work_date]  DEFAULT (getdate()) FOR [work_date],
		CONSTRAINT [DF_Table_1_hours]  DEFAULT ((0)) FOR [minutes],
		CONSTRAINT [DF_webolize_timeentries_created_by]  DEFAULT ((-1)) FOR [created_by],
		CONSTRAINT [DF_webolize_timeentries_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [PK_webolize_timeentries] PRIMARY KEY CLUSTERED 
		(
			[pk_id]
		)  ON [PRIMARY] 
END
--GO

IF NOT EXISTS(SELECT [name] 
	  FROM 	 sysobjects 
	  WHERE  [name] = N'webolize_vendors' 
	  AND 	 type = 'U')
BEGIN
	CREATE TABLE [dbo].[webolize_vendors](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[short_name] [nvarchar](32) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[full_name] [nvarchar](200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[contact_info] [nvarchar](200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[account_info] [varchar](100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[fk_topic] [int] NOT NULL,
		[active] [bit] NOT NULL,
		[created_by] [int] NULL,
		[created_date] [datetime] NOT NULL
	) ON [PRIMARY]


	ALTER TABLE [dbo].[webolize_vendors] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_vendors_fk_topic]  DEFAULT ((-1)) FOR [fk_topic],
		CONSTRAINT [DF_webolize_vendors_active]  DEFAULT ((1)) FOR [active],		
		CONSTRAINT [DF_webolize_vendors_created_by]  DEFAULT ((-1)) FOR [created_by],
		CONSTRAINT [DF_webolize_vendors_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [PK_webolize_vendors] PRIMARY KEY CLUSTERED 
		(
			[pk_id] ASC
		) ON [PRIMARY]

	INSERT INTO [dbo].[webolize_vendors]
	   ([short_name],[full_name],[created_by])
	VALUES
	   ('USPO','US Post Office',1)

	INSERT INTO [dbo].[webolize_vendors]
	   ([short_name],[full_name],[created_by])
	VALUES
	   ('UPS','UPS',1)

	INSERT INTO [dbo].[webolize_vendors]
	   ([short_name],[full_name],[created_by])
	VALUES
	   ('Fedex','Fedex',1)

	INSERT INTO [dbo].[webolize_vendors]
	   ([short_name],[full_name],[created_by])
	VALUES
	   ('DHL','DHL',1)
END
--GO

IF NOT EXISTS(SELECT [name] 
	  FROM 	 sysobjects 
	  WHERE  [name] = N'webolize_expensecodes' 
	  AND 	 type = 'U')
BEGIN
	CREATE TABLE [dbo].[webolize_expensecodes](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[full_name] [nvarchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
		[description] [nvarchar](200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[markup_multiplier] [decimal](5, 4) NULL,
		[active] [bit] NOT NULL,
		[created_date] [datetime] NOT NULL,
		[created_by] [int] NOT NULL
	) ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_expensecodes] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_expensecodes_active]  DEFAULT ((1)) FOR [active],
		CONSTRAINT [DF_webolize_expensecodes_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [DF_webolize_expensecodes_created_by]  DEFAULT ((-1)) FOR [created_by],
		CONSTRAINT [PK_webolize_expensecodes] PRIMARY KEY CLUSTERED 
		(
			[pk_id] ASC
		) ON [PRIMARY]
		
	INSERT INTO [dbo].[webolize_expensecodes]
	   ([full_name],[description],[markup_multiplier],[created_by])
	VALUES
	   ('None','No Markup', 1.00,1)

END
--GO

IF NOT EXISTS(SELECT [name] 
	  FROM 	 sysobjects 
	  WHERE  [name] = N'webolize_expenses' 
	  AND 	 type = 'U')
BEGIN
	CREATE TABLE [dbo].[webolize_expenses](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[fk_project] [int] NOT NULL,
		[fk_expensecode] [int] NOT NULL,
		[fk_vendor] [int] NOT NULL,
		[expense_date] [datetime] NULL,
		[unit_cost] [decimal](10, 3) NULL,
		[description] [nvarchar](100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[created_date] [datetime] NOT NULL,
		[created_by] [int] NOT NULL
	) ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_expenses] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_expenses_expense_date]  DEFAULT (getdate()) FOR [expense_date],
		CONSTRAINT [DF_webolize_expenses_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [DF_webolize_expenses_created_by]  DEFAULT ((-1)) FOR [created_by],
		CONSTRAINT [PK_webolize_expenses] PRIMARY KEY CLUSTERED 
		(
			[pk_id] ASC
		) ON [PRIMARY]
END
--GO


IF NOT EXISTS(SELECT [name] 
	  FROM 	 sysobjects 
	  WHERE  [name] = N'webolize_contacts' 
	  AND 	 type = 'U')
BEGIN
	CREATE TABLE [dbo].[webolize_contacts](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[first_name] [nvarchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[last_name] [nvarchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[email] [nvarchar](256) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[phone] [varchar](32) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[address] [nvarchar](256) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[password] [nvarchar](32) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[fk_department] [int] NOT NULL,
		[fk_issue] [int] NOT NULL,
		[created_date] [datetime] NOT NULL,
		[created_by] [int] NOT NULL
	) ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_contacts] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_contacts_last_name]  DEFAULT (N'--') FOR [last_name],
		CONSTRAINT [DF_webolize_contacts_fk_department]  DEFAULT ((-1)) FOR [fk_department],
		CONSTRAINT [DF_webolize_contacts_fk_issue]  DEFAULT ((-1)) FOR [fk_issue],
 		CONSTRAINT [DF_webolize_contacts_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [DF_webolize_contacts_created_by]  DEFAULT ((-1)) FOR [created_by],
		CONSTRAINT [PK_webolize_contacts] PRIMARY KEY CLUSTERED 
		(
			[pk_id] ASC
		) ON [PRIMARY]

END
--GO



IF NOT EXISTS(SELECT [name] 
	  FROM 	 sysobjects 
	  WHERE  [name] = N'webolize_clients' 
	  AND 	 type = 'U')
BEGIN
	CREATE TABLE [dbo].[webolize_clients](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[organization] [nvarchar](200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[short_name] [nvarchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
		[fk_contact] [int] NOT NULL,
		[fk_contact_address] [int] NOT NULL,
		[fk_issue] [int] NOT NULL
	) ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_clients] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_clients_fk_contact_address]  DEFAULT ((-1)) FOR [fk_contact_address],
		CONSTRAINT [DF_webolize_clients_fk_contact]  DEFAULT ((-1)) FOR [fk_contact],
		CONSTRAINT [DF_webolize_clients_fk_issue]  DEFAULT ((-1)) FOR [fk_issue],
		CONSTRAINT [PK_webolize_clients] PRIMARY KEY CLUSTERED
		(
			[pk_id] ASC
		) ON [PRIMARY]

END
--GO

IF NOT EXISTS(SELECT [name] 
	  FROM 	 sysobjects 
	  WHERE  [name] = N'webolize_billablemultipliers' 
	  AND 	 type = 'U')
BEGIN
	CREATE TABLE [dbo].[webolize_billablemultipliers](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[multiplier_type] [varchar](32) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL CONSTRAINT [DF_webolize_billablemultipliers_multiplier_type]  DEFAULT ('TAX'),
		[multiplier_name] [varchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
		[multiplier_percent] [decimal](6, 3) NOT NULL,
		[active] [bit] NOT NULL,
		[created_date] [datetime] NOT NULL,
		[created_by] [int] NOT NULL
	) ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_billablemultipliers] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_billablemultipliers_multiplier_percent]  DEFAULT ((0)) FOR [multiplier_percent],
		CONSTRAINT [DF_webolize_billablemultipliers_active]  DEFAULT ((1)) FOR [active],
		CONSTRAINT [DF_webolize_billablemultipliers_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [DF_webolize_billablemultipliers_created_by]  DEFAULT ((-1)) FOR [created_by],
		CONSTRAINT [PK_webolize_billablemultipliers] PRIMARY KEY CLUSTERED
		(
			[pk_id] ASC
		) ON [PRIMARY]

INSERT INTO [dbo].[webolize_billablemultipliers]
		( [multiplier_type], [multiplier_name], [multiplier_percent], [active], [created_by])
     VALUES
		('TAX', 'No Tax', 1.0, 1, 1)

END
--GO


IF NOT EXISTS(SELECT [name] 
	  FROM 	 sysobjects 
	  WHERE  [name] = N'webolize_billabletypes' 
	  AND 	 type = 'U')
BEGIN

	CREATE TABLE [dbo].[webolize_billabletypes](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[type_name] [nvarchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
		[description] [nvarchar](4000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[unit_cost] [money] NULL,
		[default_quantity] [int] NULL,
		[fk_default_tax] [int] NULL,
		[inventory_quantity] [int] NULL,
		[inventory_date] [datetime] NULL,
		[unique_name] [varchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[active] [bit] NOT NULL,
		[category_name] [nvarchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[fk_category] [int] NOT NULL,
		[fk_issue] [int] NOT NULL
	 ) ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_billabletypes] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_billabletypes_default_quantity]  DEFAULT ((1)) FOR [default_quantity],
		CONSTRAINT [DF_webolize_billabletypes_inventory_date]  DEFAULT (getdate()) FOR [inventory_date],
		CONSTRAINT [DF_webolize_billabletypes_active]  DEFAULT ((1)) FOR [active],
		CONSTRAINT [DF_webolize_billabletypes_fk_category]  DEFAULT ((-1)) FOR [fk_category],
		CONSTRAINT [DF_webolize_billabletypes_fk_issue]  DEFAULT ((-1))	FOR [fk_issue],
		CONSTRAINT [PK_webolize_billabletypes] PRIMARY KEY CLUSTERED 		
		(
			[pk_id] ASC
		) ON [PRIMARY]

INSERT INTO [dbo].[webolize_billabletypes]
		([type_name], [description], [unit_cost], [default_quantity], [active] )
     VALUES
		('Service', 'Time entries', 1.0, 1, 1)

INSERT INTO [dbo].[webolize_billabletypes]
		([type_name], [description], [unit_cost], [default_quantity], [active] )
     VALUES
		('Expense', 'items specifically ordered for the client project', 1.0, 1, 1)

INSERT INTO [dbo].[webolize_billabletypes]
		([type_name], [description], [unit_cost], [default_quantity], [active] )
     VALUES
		('Product', 'items that are sold', 1.0, 1, 1)

INSERT INTO [dbo].[webolize_billabletypes]
		([type_name], [description], [unit_cost], [default_quantity], [active] )
     VALUES
		('Other', 'other entry types', 1.0, 1, 1)

END
--GO

IF NOT EXISTS(SELECT [name] 
	  FROM 	 sysobjects 
	  WHERE  [name] = N'webolize_invoices' 
	  AND 	 type = 'U')
BEGIN

	CREATE TABLE [dbo].[webolize_invoices](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[fk_project] [int] NOT NULL,
		[invoice_number] [varchar](32) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[invoice_date] [datetime] NOT NULL,
		[client_address] [nvarchar](200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[po_number] [varchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[discount_name] [varchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[discount_percent] [decimal](6, 3) NULL,
		[sent_status] [varchar](20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[sent_date] [datetime] NULL,
		[sent_delivery] [varchar](20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[fk_taxes] [int] NOT NULL,
		[fk_terms] [int] NOT NULL,
		[fk_notes] [int] NOT NULL,
		[subtotal] [money] NULL,
		[discount] [money] NULL,
		[taxes] [money] NULL,
		[total] [money] NULL,
		[calculated_date] [datetime] NOT NULL,
		[created_date] [datetime] NOT NULL,
		[created_by] [int] NOT NULL
	) ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_invoices] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_invoices_fk_project]  DEFAULT ((-1)) FOR [fk_project],
		CONSTRAINT [DF_webolize_invoices_invoice_date]  DEFAULT (getdate()) FOR [invoice_date],
		CONSTRAINT [DF_webolize_invoices_fk_taxes]  DEFAULT ((-1)) FOR [fk_taxes],
		CONSTRAINT [DF_webolize_invoices_fk_terms]  DEFAULT ((-1)) FOR [fk_terms],
		CONSTRAINT [DF_webolize_invoices_fk_notes]  DEFAULT ((-1)) FOR [fk_notes],
		CONSTRAINT [DF_webolize_invoices_calculated_date]  DEFAULT (getdate()) FOR [calculated_date],
		CONSTRAINT [DF_webolize_invoices_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [DF_webolize_invoices_created_by]  DEFAULT ((-1)) FOR [created_by],
		CONSTRAINT [PK_webolize_invoices] PRIMARY KEY CLUSTERED
		(
			[pk_id] ASC
		) ON [PRIMARY]

END
--GO

IF NOT EXISTS(SELECT [name] 
	  FROM 	 sysobjects 
	  WHERE  [name] = N'webolize_billableitems' 
	  AND 	 type = 'U')
BEGIN

	CREATE TABLE [dbo].[webolize_billableitems](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[billable_type] [varchar](32) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
		[fk_invoice] [int] NOT NULL,
		[fk_estimate] [int] NOT NULL,
		[fk_billableitem_type] [int] NOT NULL,
		[description] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[unit_cost] [money] NULL,
		[quantity] [int] NULL,
		[tax] [money] NULL,
		[price] [money] NULL
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_billableitems] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_billableitems_billable_type]  DEFAULT ('INVOICE') FOR [billable_type],
		CONSTRAINT [DF_webolize_billableitems_fk_invoice]  DEFAULT ((-1)) FOR [fk_invoice],
		CONSTRAINT [DF_webolize_billableitems_fk_estimate]  DEFAULT ((-1)) FOR [fk_estimate],
		CONSTRAINT [DF_webolize_billableitems_fk_billableitem_type]  DEFAULT ((-1)) FOR [fk_billableitem_type],
		CONSTRAINT [PK_webolize_billableitems] PRIMARY KEY CLUSTERED
		(
			[pk_id] ASC
		) ON [PRIMARY]

END
--GO


IF NOT EXISTS(SELECT [name] 
	  FROM 	 sysobjects 
	  WHERE  [name] = N'webolize_billablenotes' 
	  AND 	 type = 'U')
BEGIN
	CREATE TABLE [dbo].[webolize_billablenotes](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[billable_type] [varchar](32) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
		[is_custom] [bit] NOT NULL,
		[title] [nvarchar](256) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[notes] [nvarchar](4000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[active] [bit] NOT NULL,
		[created_date] [datetime] NOT NULL,
		[created_by] [int] NOT NULL
	) ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_billablenotes] WITH NOCHECK ADD
		CONSTRAINT [DF_webolize_billablenotes_billable_type]  DEFAULT ('INVOICE') FOR [billable_type],
		CONSTRAINT [DF_webolize_billablenotes_isCustom]  DEFAULT ((0)) FOR [is_custom],
		CONSTRAINT [DF_webolize_billablenotes_active]  DEFAULT ((1)) FOR [active],
		CONSTRAINT [DF_webolize_billablenotes_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [DF_webolize_billablenotes_created_by]  DEFAULT ((-1)) FOR [created_by],
		CONSTRAINT [PK_webolize_billablenotes] PRIMARY KEY CLUSTERED
		(
			[pk_id] ASC
		) ON [PRIMARY]

INSERT INTO [dbo].[webolize_billablenotes]
		( [billable_type], [is_custom], [title], [notes], [active], [created_by] )
     VALUES
		('NOTE', 0, 'No Notes specified', '', 1, 1)

INSERT INTO [dbo].[webolize_billablenotes]
		( [billable_type], [is_custom], [title], [notes], [active], [created_by] )
     VALUES
		('TERMS', 0, 'No Terms specified', '', 1, 1)

END
--GO

-- INSTALL Sample Data
IF NOT EXISTS(SELECT	pk_id
				FROM	webolize_projects)
BEGIN

DECLARE @SampleContactID INT
DECLARE @SampleClientID INT
DECLARE @SampleProjectID INT

-- contact
	INSERT INTO [dbo].[webolize_contacts]
	   ([first_name],[last_name],[email],[phone],[address],[created_date],[created_by])
	VALUES
	   ('Unknown','Contact','','','',GETDATE(), 1)

	SELECT @SampleContactID = Scope_Identity()

-- client
	INSERT INTO [dbo].[webolize_clients]
	   ([organization],[short_name],[fk_contact])
	VALUES
	   ('NorthBreeze LLC','NorthBreeze', @SampleContactID )

	SELECT @SampleClientID = Scope_Identity()

-- project
	INSERT INTO [dbo].[webolize_projects]
			   ([forum_type],[forum_type_version],[forum_name],[description],[short_name],[contact_person],[fk_department],[created_by],[closed_date])
		 VALUES
			   ('Webolize.Project',70,'NorthBreeze Website','Sample time tracking project','SMP',@SampleContactID, @SampleClientID,1,'12/31/9999 11:59:59 PM')

	SELECT @SampleProjectID = Scope_Identity()


END	-- sample

-- CUYAHOGA SPECIFIC
--
--  Table data
--
SET DATEFORMAT ymd

DECLARE @moduletypeid int

INSERT INTO cuyahoga_moduletype ([name], assemblyname, classname, path, editpath, inserttimestamp, updatetimestamp) 
	VALUES ('Webolize-TimeTracker', 'Webolize.TimeTracker', 'Webolize.TimeTracker.TimeTrackerModule', 'Modules/Webolize-TimeTracker/TimeEntryAll.ascx', 'Modules/Webolize-TimeTracker/Admin/Admin.aspx', '2007-06-05 12:00:00', '2007-06-05 12:00:00')

SELECT @moduletypeid = Scope_Identity()

INSERT INTO cuyahoga_modulesetting (moduletypeid, name, friendlyname, settingdatatype, iscustomtype, isrequired) VALUES (@moduletypeid, 'ISSUETRACKER_SECTION', 'Section ID of IssueTracker (or -1)', 'System.Int16', 0, 1)
--GO

INSERT INTO cuyahoga_version ([assembly], major, minor, patch) VALUES ('Webolize.TimeTracker', 0, 8, 0)
GO
